8ce7da98082db69f86314bf79d8f69978e008455
angie
  Fri Apr 28 16:43:36 2017 -0700
hgVai was crashing when there was a new snpNNN table in the database but not yet in trackDb.  Now make sure to use the latest SNPs track not just the latest table.  refs #19272

diff --git src/hg/inc/hdb.h src/hg/inc/hdb.h
index 060b06a..0a8564d 100644
--- src/hg/inc/hdb.h
+++ src/hg/inc/hdb.h
@@ -953,24 +953,24 @@
 #define cladeTableConfVariable  "cladeTableName"
 #define defaultCladeTableName  "clade"
 
 char *dbDbTable();
 /* Return the name of the dbDb table. */
 
 char *cladeTable();
 /* Return the name of the clade table. */
 
 char *defaultDbTable();
 /* Return the name of the defaultDb table. */
 
 char *genomeCladeTable();
 /* Return the name of the genomeClade table. */
 
-char *hFindLatestSnpTable(char *db, char *suffix);
-/* Return the name of the 'snp1__<suffix>' table with the highest build number, if any.
+struct trackDb *hFindLatestSnpTrack(char *db, char *suffix, struct trackDb **pFullTrackList);
+/* Return the 'snpNNN<suffix>' track with the highest build number, if any.
  * suffix may be NULL to get the 'All SNPs' table (as opposed to Common, Flagged, Mult). */
 
 char *hFindLatestSnpTableConn(struct sqlConnection *conn, char *suffix);
 /* Return the name of the 'snp1__<suffix>' table with the highest build number, if any.
  * suffix may be NULL to get the 'All SNPs' table (as opposed to Common, Flagged, Mult). */
 
 #endif /* HDB_H */